
# Slot: window_size


Size of the context and target nodes for node2vec.

URI: [https://w3id.org/neat/nodeEmbeddingsParams__window_size](https://w3id.org/neat/nodeEmbeddingsParams__window_size)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [NodeEmbeddingsParams](NodeEmbeddingsParams.md)
